@@ -1,3 +1,7 @@
+##
+##  d i s t m a t . R  Distance matrix and Hausdorff dimension
+##
+
 # If a is m x r and b is n x r then 
 #
 #   apply(outer(a,t(b),"-"),c(1,4),function(x)sqrt(sum(diag(x*x))))
@@ -9,6 +13,7 @@
 #
 # The following code is 10-100 times faster.
 
+
 distmat <- function(X, Y)
 #   Computes Euclidean distance between two vectors as:
 #       ||A-B|| = sqrt ( ||A||^2 + ||B||^2 - 2*A.B )
@@ -28,3 +33,20 @@ distmat <- function(X, Y)
 
     sqrt(XX + YY - 2*XY)
 }
+
+
+hausdorff_dist <- function(P, Q) {
+    stopifnot(is.numeric(P), is.numeric(Q))
+    if (is.vector(P)) P <- matrix(P, ncol = 1)
+    if (is.vector(Q)) Q <- matrix(Q, ncol = 1)
+    if (ncol(P) != ncol(Q))
+        stop("'P' and 'Q' must have the same number of columns.")
+
+    D <- distmat(P, Q)
+
+    # directional Hausdorff dimension
+    dhd_PQ <- max(apply(D, 1, min))
+    dhd_QP <- max(apply(D, 2, min))
+
+    return(max(dhd_PQ, dhd_QP))
+}
