@@ -66,3 +66,23 @@ modinv <- function(n, m) {
 	if (v[1] == 0 || v[1] > 1) return(NA)
 	if (v[2] >= 0) v[2] else v[2] + m
 }
+
+modlin <- function(a, b, n) {
+    stopifnot(is.numeric(a), is.numeric(b), is.numeric(n))
+    if (length(a) != 1 || length(b) != 1 || length(n) != 1 ||
+        floor(a) != ceiling(a) || floor(b) != ceiling(b) || floor(n) != ceiling(n) ||
+        a < 1 || b < 1 || n < 1)
+        stop("All inputs 'a', 'b', 'n' must be integers.")
+
+    def <- extGCD(a, n)
+    d <- def[1]; e <- def[2]; f <- def[3]
+
+    x <- c()
+    if (b %% d == 0) {
+        x0 <- (e * (b/d)) %% n
+        for (i in 0:(d-1)) {
+            x <- c(x, (x0 + i*(n/d)) %% n)
+        }
+    }
+    return(x)
+}
